@@ -2,6 +2,7 @@
 
 import collections
 import datetime
+import itertools
 import logging
 from pathlib import Path
 from typing import Dict, Iterable, List, Optional, Sequence, Tuple, TypeVar
@@ -24,8 +25,24 @@ def files_to_combine(config: Config) -> List[Path]:
     The files are returned in the order they should be processed.
 
     """
-    pattern = "**/*.{}".format(config.format)
-    return sorted(Path(config.fragment_directory).glob(pattern))
+    return sorted(
+        itertools.chain.from_iterable(
+            [
+                Path(config.fragment_directory).glob(pattern)
+                for pattern in ["*.rst", "*.md"]
+            ]
+        )
+    )
+
+
+def sections_from_file(config: Config, filename: Path) -> SectionDict:
+    """
+    Collect the sections from a file.
+    """
+    format_tools = get_format_tools(filename.suffix.lstrip("."), config)
+    text = filename.read_text().rstrip()
+    file_sections = format_tools.parse_text(text)
+    return file_sections
 
 
 def combine_sections(config: Config, files: Iterable[Path]) -> SectionDict:
@@ -34,15 +51,9 @@ def combine_sections(config: Config, files: Iterable[Path]) -> SectionDict:
     """
     sections = collections.defaultdict(list)  # type: SectionDict
     for file in files:
-        format_tools = get_format_tools(file.suffix.lstrip("."), config)
-        with file.open() as f:
-            text = f.read().rstrip()
-        if config.categories:
-            file_sections = format_tools.parse_text(text)
-            for section, paragraphs in file_sections.items():
-                sections[section].extend(paragraphs)
-        else:
-            sections[None].append(text)
+        file_sections = sections_from_file(config, file)
+        for section, paragraphs in file_sections.items():
+            sections[section].extend(paragraphs)
     return sections
 
 
@@ -50,7 +61,9 @@ T = TypeVar("T")
 K = TypeVar("K")
 
 
-def order_dict(d: Dict[Optional[K], T], keys: Sequence[Optional[K]]) -> Dict[Optional[K], T]:
+def order_dict(
+    d: Dict[Optional[K], T], keys: Sequence[Optional[K]]
+) -> Dict[Optional[K], T]:
     """
     Produce an OrderedDict of `d`, but with the keys in `keys` order.
     """
@@ -82,12 +95,24 @@ def cut_at_line(text: str, marker: str) -> Tuple[str, str]:
 
 
 @click.command()
-@click.option("--add/--no-add", default=None, help="'git add' the updated changelog file.")
-@click.option("--edit/--no-edit", default=None, help="Open the changelog file in your text editor.")
-@click.option("--keep", is_flag=True, help="Keep the fragment files that are collected.")
-@click.option("--version", default=None, help="The version name to use for this entry.")
+@click.option(
+    "--add/--no-add", default=None, help="'git add' the updated changelog file."
+)
+@click.option(
+    "--edit/--no-edit",
+    default=None,
+    help="Open the changelog file in your text editor.",
+)
+@click.option(
+    "--keep", is_flag=True, help="Keep the fragment files that are collected."
+)
+@click.option(
+    "--version", default=None, help="The version name to use for this entry."
+)
 @click_log.simple_verbosity_option(logger)
-def collect(add: Optional[bool], edit: Optional[bool], keep: bool, version: str) -> None:
+def collect(
+    add: Optional[bool], edit: Optional[bool], keep: bool, version: str
+) -> None:
     """
     Collect fragments and produce a combined entry in the CHANGELOG file.
     """
@@ -103,9 +128,18 @@ def collect(add: Optional[bool], edit: Optional[bool], keep: bool, version: str)
     sections = order_dict(sections, [None] + config.categories)
 
     changelog = Path(config.output_file)
+    newline = ""
     if changelog.exists():
-        changelog_text = changelog.read_text()
-        text_before, text_after = cut_at_line(changelog_text, config.insert_marker)
+        with changelog.open("r") as f:
+            changelog_text = f.read()
+            if f.newlines:  # .newlines may be None, str, or tuple
+                if isinstance(f.newlines, str):
+                    newline = f.newlines
+                else:
+                    newline = f.newlines[0]
+        text_before, text_after = cut_at_line(
+            changelog_text, config.insert_marker
+        )
     else:
         text_before = ""
         text_after = ""
@@ -115,24 +149,27 @@ def collect(add: Optional[bool], edit: Optional[bool], keep: bool, version: str)
         "date": datetime.datetime.now(),
         "version": version or config.version,
     }
-    new_title = jinja2.Template(config.entry_title_template).render(config=config, **title_data)
+    new_title = jinja2.Template(config.entry_title_template).render(
+        config=config, **title_data
+    )
     if new_title.strip():
         new_header = format_tools.format_header(new_title)
     else:
         new_header = ""
     new_text = format_tools.format_sections(sections)
-    changelog.write_text(text_before + new_header + new_text + text_after)
+    with changelog.open("w", newline=newline or None) as f:
+        f.write(text_before + new_header + new_text + text_after)
 
     if edit:
-        git_edit(str(changelog))
+        git_edit(changelog)
 
     if add:
-        git_add(str(changelog))
+        git_add(changelog)
 
     if not keep:
         for file in files:
             logger.info("Deleting fragment file {}".format(file))
             if add:
-                git_rm(str(file))
+                git_rm(file)
             else:
                 file.unlink()
