@@ -1,5 +1,7 @@
 """ReStructured text knowledge for scriv."""
 
+import re
+
 from .format import FormatTools, SectionDict
 
 
@@ -8,13 +10,41 @@ class RstTools(FormatTools):
 
     HEADER_CHARS = "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~"
 
-    def _is_underline(self, text: str) -> bool:
+    def _is_underline(self, line: str) -> bool:
         """
-        Determine if `text` is a valid RST underline.
+        Determine if `line` is a valid RST underline.
         """
-        return len(text) >= 3 and text[0] in self.HEADER_CHARS and len(set(text)) == 1
+        return (
+            len(line) >= 3
+            and line[0] in self.HEADER_CHARS
+            and len(set(line)) == 1
+        )
 
-    def parse_text(self, text: str) -> SectionDict:  # noqa: D102 (inherited docstring)
+    def _is_comment(self, line: str) -> bool:
+        """
+        Determine if a line is a comment.
+
+        RST syntax is subtle, so we have to check for other kinds of dot-dot
+        lines that are not comments.
+        """
+        if line.startswith(".."):
+            if line == "..":
+                return True
+            elif line.startswith(("...", ".. _", ".. [", ".. |")):
+                # It's an underline, hyperlink, citation, or substitution, so
+                # not a comment.
+                return False
+            elif re.search(r"^.. [\w_+:.-]+::", line):
+                # A directive: not a comment.
+                return False
+            else:
+                return True
+        else:
+            return False
+
+    def parse_text(
+        self, text: str
+    ) -> SectionDict:  # noqa: D102 (inherited docstring)
         # Parse a very restricted subset of rst.
         sections = {}  # type: SectionDict
 
@@ -27,7 +57,7 @@ class RstTools(FormatTools):
         for line in lines:
             line = line.rstrip()
 
-            if line == ".." or line[:3] == ".. ":
+            if self._is_comment(line):
                 # Comment, do nothing.
                 continue
 
@@ -35,7 +65,7 @@ class RstTools(FormatTools):
                 # Section underline. Previous line was the heading.
                 if paragraphs is not None:
                     # Heading was made a paragraph, undo that.
-                    if paragraphs[-1] == prev_line + "\n":  # pylint: disable=unsubscriptable-object
+                    if paragraphs[-1] == prev_line + "\n":
                         paragraphs.pop()
                 paragraphs = sections.setdefault(prev_line, [])
                 paragraphs.append("")
@@ -63,10 +93,20 @@ class RstTools(FormatTools):
         }
         return sections
 
-    def format_header(self, text: str) -> str:  # noqa: D102 (inherited docstring)
-        return "\n" + text + "\n" + self.config.rst_header_chars[0] * len(text) + "\n"
+    def format_header(
+        self, text: str
+    ) -> str:  # noqa: D102 (inherited docstring)
+        return (
+            "\n"
+            + text
+            + "\n"
+            + self.config.rst_header_chars[0] * len(text)
+            + "\n"
+        )
 
-    def format_sections(self, sections: SectionDict) -> str:  # noqa: D102 (inherited docstring)
+    def format_sections(
+        self, sections: SectionDict
+    ) -> str:  # noqa: D102 (inherited docstring)
         lines = []
         for section, paragraphs in sections.items():
             if section:
